@@ -37,8 +37,10 @@ the files:
 #define MAXNUMOFCURVES 100
 #define MAXNUMOFDETS  1000
 
+/* commented by MB Nov 2020
 #define BUFFSIZE 4000
-
+#define BUFSIZE 4000
+*/ 
 
 //the "every" thinning subsampling parameter is EVERY_MULT*All.Dim()
 #define EVERY_MULT 5
@@ -51,18 +53,18 @@ the files:
 
 
 // [[Rcpp::export]]
-int bacon( std::string inputfile1, std::string outputfile1 , int ssize, std::string dircc) {// Command line: bacon inputfile outputfile
+int bacon( std::string inputfile1, std::string outputfile1, int ssize, std::string dircc) {// Command line: bacon inputfile outputfile
 //
 
   char *inputfile = new char[inputfile1.length() + 1];
 //  printf("%s\n", inputfile1.c_str());
   strcpy(inputfile, inputfile1.c_str());
   //JEV avoid warning int i=0; i<inputfile1.length() ; i++
-  //for (unsigned int i=0; i<inputfile1.length() ; i++){   // MB commented this Oct 2020 as it just repeats printing the name/location of the bacon file
+//  for (unsigned int i=0; i<inputfile1.length() ; i++){   // MB remove this Oct 2020 as it just repeats printing the name/location of the bacon file?
 
 //     printf("'%c' ", inputfile1.c_str()[i]);
-     // Rprintf("'%c' ", inputfile1.c_str()[i]);
- //     Rprintf("%c", inputfile1.c_str()[i]);
+ //     Rprintf("'%c' ", inputfile1.c_str()[i]);
+//    Rprintf("%c", inputfile1.c_str()[i]);
 //  }
 
   char *outputfile = new char[outputfile1.length() + 1];
